[libpng16] Removed dubious "#if INT_MAX" test from png.h that was added to

libpng-1.6.19bet02 (John Bowler).
diff --git a/ANNOUNCE b/ANNOUNCE
index 8d5709e..dfc8d13 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -59,7 +59,10 @@
     to the LICENSE file, png.h, and the man page.
   Restored "& 0xff" in png_save_uint_16() and png_save_uint_32() that
     were accidentally removed from libpng-1.6.17. 
-  Changed PNG_INFO_cHNK from 0xnnnn to 0xnnnnU (Robert C. Seacord).
+  Changed PNG_INFO_cHNK and PNG_FREE_cHNK from 0xnnnn to 0xnnnnU in png.h
+   (Robert C. Seacord).
+  Removed dubious "#if INT_MAX" test from png.h that was added to
+   libpng-1.6.19bet02 (John Bowler).
 
 Send comments/corrections/commendations to png-mng-implement at lists.sf.net
 (subscription required; visit
diff --git a/CHANGES b/CHANGES
index 0c3f8ef..813a9d4 100644
--- a/CHANGES
+++ b/CHANGES
@@ -5518,7 +5518,10 @@
     to the LICENSE file, png.h, and the man page.
   Restored "& 0xff" in png_save_uint_16() and png_save_uint_32() that
     were accidentally removed from libpng-1.6.17. 
-  Changed PNG_INFO_cHNK from 0xnnnn to 0xnnnnU (Robert C. Seacord).
+  Changed PNG_INFO_cHNK and PNG_FREE_cHNK from 0xnnnn to 0xnnnnU in png.h
+   (Robert C. Seacord).
+  Removed dubious "#if INT_MAX" test from png.h that was added to
+   libpng-1.6.19bet02 (John Bowler).
 
 Send comments/corrections/commendations to png-mng-implement at lists.sf.net
 (subscription required; visit
diff --git a/png.h b/png.h
index 3946c37..4c819e8 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.6.22beta03, February 10, 2016
  *
  * Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -12,7 +12,7 @@
  * Authors and maintainers:
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
  *   libpng versions 0.97, January 1998, through 1.6.22beta03, February 10, 2016:
  *     Glenn Randers-Pehrson.
  *   See also "Contributing Authors", below.
  */
@@ -25,7 +25,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.0.7, July 1, 2000, through 1.6.22beta03, February 10, 2016, are
  * Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
  * derived from libpng-1.0.6, and are distributed according to the same
  * disclaimer and license as libpng-1.0.6 with the following individuals
@@ -231,7 +231,7 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    February 10, 2016
+ *    February 13, 2016
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
@@ -301,7 +301,7 @@
 /* Version information for png.h - this should match the version in png.c */
 #define PNG_LIBPNG_VER_STRING "1.6.22beta03"
 #define PNG_HEADER_VERSION_STRING \
-     " libpng version 1.6.22beta03 - February 10, 2016\n"
+     " libpng version 1.6.22beta03 - February 13, 2016\n"
 
 #define PNG_LIBPNG_VER_SONUM   16
 #define PNG_LIBPNG_VER_DLLNUM  16
@@ -766,9 +766,7 @@
 #define PNG_INFO_iCCP 0x1000U  /* ESR, 1.0.6 */
 #define PNG_INFO_sPLT 0x2000U  /* ESR, 1.0.6 */
 #define PNG_INFO_sCAL 0x4000U  /* ESR, 1.0.6 */
-#if INT_MAX >= 0x8000 /* else this might break */
 #define PNG_INFO_IDAT 0x8000U  /* ESR, 1.0.6 */
-#endif
 
 /* This is used for the transformation routines, as some of them
  * change these values for the row.  It also should enable using
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.6.22beta03, February 10, 2016
+ * libpng version 1.6.22beta03, February 13, 2016
  *
  * Copyright (c) 1998-2002,2004,2006-2016 Glenn Randers-Pehrson
@@ -12,7 +12,7 @@
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
- *   libpng versions 0.97, January 1998, through 1.6.22beta03, February 10, 2016:
+ *   libpng versions 0.97, January 1998, through 1.6.22beta03, February 13, 2016:
  *     Glenn Randers-Pehrson.
  *   See also "Contributing Authors", below.
@@ -25,7 +25,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.0.7, July 1, 2000, through 1.6.22beta03, February 10, 2016, are
+ * libpng versions 1.0.7, July 1, 2000, through 1.6.22beta03, February 13, 2016, are
  * Copyright (c) 2000-2002, 2004, 2006-2016 Glenn Randers-Pehrson, are
  * derived from libpng-1.0.6, and are distributed according to the same